@@ -3,7 +3,7 @@ from dynaconf import Dynaconf
 CONFIG = Dynaconf(
     envvar_prefix="AKB",
     settings_files=["config.yaml"],
-    env_switcher="AKB_ENV",
+    env_switcher="ENV",
     core_loaders=["YAML"],
     environments=True,
 )
